bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 2. Aventiure
___________________________________________________ #### Aventivre von Sifride
| ### o wohs in Niderlanden eins richen kvniges kimt ### des vater hiez Sigemunt sin muoter Sigelint ### in einer burge riche witen wol bekant ### niden bi dem Rine diu was ze Santen genant
###### 21 | ### Ich sage iv von dem degne wie schoene der wart ### sin lip vor allen schanden was vil wol bewart ### starch vnde mere wart sit der kuene man ### hey waz er grozer ern ze diser werlde gewan
###### 22 | ### Sifrit was geheizen der selbe degen gvot ### er versvohte vil der riche durch ellenthaften mvot ### durch sines libes sterke reit er in menigiv lant ### < > er sneller degne ze den Burgonden vant
###### 23 | ### In sinen besten ziten bi sinen ivngen tagen ### man mohte michel <wnder> von Sifride sagen ### waz eren an im <wuohs> vn– wie schoene was sin lip ### sit heten in ze minne diu vil wætlichen wip
###### 24 | ### Man zoch in mit dem flizze als im daz wol gezam ### von sin selbes mvote waz tvgent er an sich nam ### des wrden sit gecieret sines vater lant ### daz man in ze allen dingen so rechte erlichen vant
###### 25 | ### Er was nu so gewahsen daz er ze hove rei ### die lute in gerne sahen manich frovwe vn– <m > meit ### im wunschten daz sin wille in immer truege dar [2a] ### holt waren im genvoge des wart der herre wol gewar
###### 26 | ### Vil selten ane hvote man riten lie daz kint ### in hiez mit kleider cieren Sigmunt vnde Sigelint ### sin pflagen ovch die wisen den ere was bekant ### des mohte er wol gewinnen beidiu lute vn– lant
###### 27 | ### Nv was er in der sterke daz er wol wafen truoch ### swes er dar zvo bedorfte des lag an im genvoch ### er begunde mit sinnen werben schoeniu wip ### die truoten wol mit ern des <schoenen> Sifrides lip
###### 28 | ### Do hiez sin uater Sigemvnt chvnden sinen man ### er wolde hochzite mit lieben frivnden han ### div mære man do fuorte in anderre kunige lant ### den fremden vn– den kunden gap er ros vn– gewant
###### 29 | ### Swa man <vant> deheinen ritter solde sin ### von arte der sinen mage diu edelen kindelin ### ladete man zvo dem lande durch die hochgecit ### mit dem iungen kunige swert genamen si sit
###### 30 | ### Von der hohcite man wnder mohte < n> ### Sigmunt vnde Sigelint die mohten eiagen ### mit gvote michel ere des teilte vil ir hant ### des sach man vil der vremden zvo in riten in daz lant
###### 31 | ### Vier hvndert swertdegne die solden tragen kleit ### mit samt Sifride vil manich schvoniu meit ### von werche was vnmvezzech wan si im waren holt ### vil der edeln steine die frovwen leiten in daz golt
###### 32 | ### die si mit porten wolden wurchen vof ir wat ### den iungen stolzen rechen des en was niht rat ### der wirt der hiez do sideln vil manigen kvenen man ### ze einen sunewenden da Sifrit ritters namen gewan
###### 33 | ### Do gie ze eime munster vil manich richer kneht ### vnde manich edel ritter die wisen heten reht ### daz si den tvmben dienden als in was e getan ### si hetten churzwile vil vn– ovch vil maniger freuden wan
###### 34 | ### Gote man do zen eren eine messe sanch ### do huop sic von den liuten vil michel gedranch ### do si ze riter wrden nach ritterlicher ê ### mit also grozen eren daz wætlich nimmer mere erge
###### 35 | ### Sie liefen da si fvnden gesatelt manich march ### in houe Sigemvndes der buhurt <wa > so starch ### daz man erdiezen horte palas vn– sal ### die hoh gemuoten degne die heten grozlichen schal
###### 36 | ### Von wisen vnd von tvmben man horte manigen stoz ### da der schefte brechen gein der hoehe doz ### trvnzune sach man vliegen fur den palas dan ### von maniges rechen hende daz wart mit flize getan
###### 37 | ### Der wirt der bat ez lazen do zoch man div march ### man sach ovch da zebrochen vil manigen buckel starch ### vil der edelen steine geuellet vf daz gras ### abe liechten schildes spangen von hvrte daz gescehen <was>
###### 38 | ### Do giengens wirtes geste da man in sitzen riet [2b] ### vil der edeln spise si von ir mvnde schiet ### vnde win der aller beste des man in vil getruoch ### den vremden vn– den kunden bot man eren da genuock
###### 39 | ### Swie vil si kurtzwile pflagen al den tach ### vil der uarnden diete ruowe sich bewach ### si dienden nach der die man da riche vant ### des wart mit lobe gecieret allez Sigmundes lant
###### 40 | ### Der herre hiez lihen Sifrit den iungen man ### lant vnde burge als er hete e getan ### sinen swertgenozen den gap do vil sin hant ### do liebte in diu reise daz si chomen in daz lant
###### 41 | ### Diu hohcit werte vntz an den sibenden tach ### Siglint div riche nach alten siten pflach ### durch ir sunes liebe si teilte rotes golt ### si chvnde ez wol gedienen daz im die lute waren holt
###### 42 | ### Vil lucel man der <varnden> armen da vant ### ros vnde cleider daz stovp in von der hant ### same si ze lebne heten niht mere wan einen tac ### ich wene nie ingesinde groezer milte ie gepflac
###### 43 | ### Mit lobelichen eren schiet sich diu hohcit ### von den richen herren horte man wol sit ### daz si den iungen wolden zeime herren han ### des gerte niht Sifrit der vil wæltliche man
###### 44 | ### Sit daz noch beide lebten Sigmunt vnde Sigelint ### niht wolde tragen krone ir beider liebez kint ### doch wolder wesen herre fur allen den gewalt ### des in dem landen vorhte der degen chuone vn– balt

<<< Übersicht <<< vorige Seite nächste Seite >>>